.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================
欢迎来到 Sage 教程
==================

Sage 是一个免费的开源数学软件，支持代数、几何、数论、密码学、数值计算及相关领域的研究和教学。
Sage 的开发模式和技术特点极其强调开放性、社区性、合作性和协作性：我们是在造车，而不是在重新发明轮子。
Sage 的总体目标是创建一个可行的、免费的、开源替代品，用来替代 Maple、Mathematica、Magma 和 MATLAB。

本教程是让你在短时间内熟悉 Sage 的最佳方式。
你可以阅读 HTML 或 PDF 版本，也可以从 Sage notebook 中阅读
（点击 ``Help``，然后点击 ``Tutorial`` 以交互方式在 Sage 中完成教程）。

此作品采用 `Creative Commons Attribution-Share Alike
3.0 License`__ 许可。

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   latex
   programming
   sagetex
   afterword
   appendix
   bibliography

索引与表格
==========

* :ref:`genindex`
* :ref:`search`
